Notifications about current changes
===================================

Users can get notifications about current changes to their personal timetables.
If the system administrator has enabled the feature, they can activate it by
setting the personal preference **Send notifications for current timetable changes** (cf. :ref:`core-user-preferences`).

The notifications are sent as standard AlekSIS notifications. In :ref:`core-notifications`, you can find more information
about the available channels and your configuration options.

